
Logout structuring
-------

**Description:**

Placing a logout link on every page that requires authentication helps the user end the 
session when he is done with the site. Ending the session helps prevent hijacking.


**Solution:**

Identify all pages that use authentication. Make a list of all pages on your site that use 
authentication then verify the presence of logout links. Examine each page that uses 
authentication to make sure it has a logout link in a location that can be 
found intuitively.

	